@@ -1,10 +1,10 @@
 #' Get current crypto market exchanges
 #'
 #' Scrape the crypto currency exchange tables from
-#' Coinmarketcap <https://coinmarketcap.com> and display
+#' CoinMarketCap <https://coinmarketcap.com> and display
 #' the results in a date frame. This can be used to conduct
 #' analysis on the exchanges or to attempt
-#' to predict arbiture.
+#' to predict exchange arbiture.
 #'
 #' @param coin string Name, symbol or slug of crypto currency, default is all tokens
 #' @param limit integer Return the top n records, default is all tokens
@@ -59,7 +59,7 @@
 #'
 getExchanges <-
   function(coin = NULL, limit = NULL, cpu_cores = NULL, start_date = NULL, end_date = NULL) {
-    cat("Retrieves coin market history from coinmarketcap. ")
+    cat("Retrieving crypto exchange information from CoinMarketCap. ")
     i <- "i"
     options(scipen = 999)
     coins <- listCoins(coin, start_date, end_date)
